Geometry

Enum Geometry 

pub enum Geometry {
    Point(Position),
    MultiPoint(Vec<Position>),
    LineString(Vec<Position>),
    MultiLineString(Vec<Vec<Position>>),
    Polygon(Vec<Vec<Position>>),
    MultiPolygon(Vec<Vec<Vec<Position>>>),
}
A GeoJSON geometry, reduced to the six types a shapefile can represent.

Variants



Point(Position)



MultiPoint(Vec<Position>)



LineString(Vec<Position>)



MultiLineString(Vec<Vec<Position>>)



Polygon(Vec<Vec<Position>>)



MultiPolygon(Vec<Vec<Vec<Position>>>)

Implementations

Source

impl Geometry

pub fn family(&self) -> Family

The shapefile geometry family this GeoJSON type has to be written as.

pub fn for_each_position(&self, visit: impl FnMut(&Position))

Visits every position in the geometry, for bounds and dimension probing.