pub struct Schema {
pub fields: Vec<Field>,
pub synthetic: bool,
}Expand description
The full set of columns, in the order they first appeared in the input.
Fields
fields: Vec<Field>synthetic: boolTrue when the only column is the one we synthesised.
Implementations